==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/ALERTEXCEPTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ALERTEXCEPTIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ALERTEXCEPTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALERTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYORGID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTEXCEPTIONID_Type", propOrder = {
    "alertid",
    "entitycode",
    "entityorgid"
})
public class ALERTEXCEPTIONID_Type {

    @XmlElement(name = "ALERTID", required = true)
    protected ALERTID_Type alertid;
    @XmlElement(name = "ENTITYCODE", required = true)
    protected String entitycode;
    @XmlElement(name = "ENTITYORGID")
    protected ORGANIZATIONID_Type entityorgid;

    /**
     * Obtient la valeur de la propriété alertid.
     * 
     * @return
     *     possible object is
     *     {@link ALERTID_Type }
     *     
     */
    public ALERTID_Type getALERTID() {
        return alertid;
    }

    /**
     * Définit la valeur de la propriété alertid.
     * 
     * @param value
     *     allowed object is
     *     {@link ALERTID_Type }
     *     
     */
    public void setALERTID(ALERTID_Type value) {
        this.alertid = value;
    }

    /**
     * Obtient la valeur de la propriété entitycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYCODE() {
        return entitycode;
    }

    /**
     * Définit la valeur de la propriété entitycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYCODE(String value) {
        this.entitycode = value;
    }

    /**
     * Obtient la valeur de la propriété entityorgid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getENTITYORGID() {
        return entityorgid;
    }

    /**
     * Définit la valeur de la propriété entityorgid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setENTITYORGID(ORGANIZATIONID_Type value) {
        this.entityorgid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/ALERTEXCEPTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ALERTEXCEPTIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ALERTEXCEPTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALERTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYORGID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALERTEXCEPTIONID_Type", propOrder = {
    "alertid",
    "entitycode",
    "entityorgid"
})
public class ALERTEXCEPTIONID_Type {

    @XmlElement(name = "ALERTID", required = true)
    protected ALERTID_Type alertid;
    @XmlElement(name = "ENTITYCODE", required = true)
    protected String entitycode;
    @XmlElement(name = "ENTITYORGID")
    protected ORGANIZATIONID_Type entityorgid;

    /**
     * Gets the value of the alertid property.
     * 
     * @return
     *     possible object is
     *     {@link ALERTID_Type }
     *     
     */
    public ALERTID_Type getALERTID() {
        return alertid;
    }

    /**
     * Sets the value of the alertid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ALERTID_Type }
     *     
     */
    public void setALERTID(ALERTID_Type value) {
        this.alertid = value;
    }

    /**
     * Gets the value of the entitycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYCODE() {
        return entitycode;
    }

    /**
     * Sets the value of the entitycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYCODE(String value) {
        this.entitycode = value;
    }

    /**
     * Gets the value of the entityorgid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getENTITYORGID() {
        return entityorgid;
    }

    /**
     * Sets the value of the entityorgid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setENTITYORGID(ORGANIZATIONID_Type value) {
        this.entityorgid = value;
    }

}
